# libgeoda

[![libgeoda Mac OSX build](https://github.com/GeoDaCenter/libgeoda/actions/workflows/osx-build.yml/badge.svg?branch=main)](https://github.com/GeoDaCenter/libgeoda/actions/workflows/osx-build.yml)

This repository contains the source code of libgeoda C++ library. 

It is used by rgeoda, pygeoda, jsgeoda and postgeoda.

libgeoda is a free and open-sourced library. It is released under the GNU General Public License (GPLv2 or later). 

Authors: Xun Li and Luc Anselin.

